pub struct ShardMap { /* private fields */ }Expand description
A map of shards assigned to a single worker thread.
Implementations
sourceimpl ShardMap
impl ShardMap
sourcepub fn get<A: Archetype>(
&mut self
) -> &mut impl Shard<Raw = A::RawEntity, Hint = <A::Ealloc as Ealloc>::AllocHint>
pub fn get<A: Archetype>( &mut self ) -> &mut impl Shard<Raw = A::RawEntity, Hint = <A::Ealloc as Ealloc>::AllocHint>
Gets the mutable shard reference.
sourcepub fn snapshot<A: Archetype>(&self) -> &Snapshot<A::RawEntity>
pub fn snapshot<A: Archetype>(&self) -> &Snapshot<A::RawEntity>
Returns a snapshot that tells what entities were allocated during last offline.
sourcepub fn borrow<A: Archetype>(&self) -> BorrowedShard<'_, A>
pub fn borrow<A: Archetype>(&self) -> BorrowedShard<'_, A>
Borrows the shard for an archetype through a RefCell.